@@ -1,7 +1,6 @@
 # Dynamic architecture support for GDB, the GNU debugger.
 
 # Copyright (C) 1998-2022 Free Software Foundation, Inc.
-# Copyright (C) 2019-2022 Intel Corporation
 
 # This file is part of GDB.
 
@@ -1643,6 +1642,19 @@ BFD target to use when generating a core file.
     printer="pstring (gdbarch->gcore_bfd_target)",
 )
 
+Method(
+    comment="""
+Optional hook to be called for additional arch specific setup
+after loading a core file.
+""",
+    type="int",
+    name="core_load_hook",
+    params=[("bfd *", "abfd")],
+    predicate=True,
+    invalid=True,
+    printer="host_address_to_string (gdbarch->core_load_hook)",
+)
+
 Value(
     comment="""
 If the elements of C++ vtables are in-place function descriptors rather
@@ -2689,41 +2701,6 @@ information about it is available via the 'info devices' command.
     invalid=False,
 )
 
-Value(
-    comment="""
-shstk_addr_byte_align is the shadow stack address alignment in bytes.
-""",
-    type="int",
-    name="shstk_addr_byte_align",
-    invalid=False,
-)
-
-Method(
-    comment="""
-Some targets support special hardware-assisted control-flow protection
-technologies.  For example, Intel's Control-flow Enforcement Technology (CET)
-provides a shadow stack and indirect branch tracking.
-
-To enable the return commmand for CET enabled targets, the functions
-get_shstk_pointer and set_shstk_pointer have to be provided to udpate the
-shadow stack pointer to match with the new frame.  If one of the functions or
-all of them are not available GDB assumes that no fixup is required.
-""",
-    type="void",
-    name="set_shstk_pointer",
-    params=[("const CORE_ADDR *", "ssp")],
-    predicate=True,
-    invalid=True,
-)
-
-Method(
-    type="void",
-    name="get_shstk_pointer",
-    params=[("CORE_ADDR *", "ssp")],
-    predicate=True,
-    invalid=True,
-)
-
 Method(
     comment="Define a custom address to place an inferior breakpoint.",
     type="CORE_ADDR",
