@@ -1,7 +1,6 @@
 /* Multi-process control for GDB, the GNU debugger.
 
    Copyright (C) 2008-2022 Free Software Foundation, Inc.
-   Copyright (C) 2020-2022 Intel Corporation
 
    This file is part of GDB.
 
@@ -1124,14 +1123,14 @@ print_devices (ui_out *uiout)
       const target_desc *tdesc = gdbarch_target_desc (inf->gdbarch);
       const std::string pci_slot
 	= tdesc_find_device_info_attribute (tdesc, "pci_slot");
-      const std::string subdevice_id
+      const std::string subdev_id
 	= tdesc_find_device_info_attribute (tdesc, "subdevice_id");
       const std::string vendor_id
 	= tdesc_find_device_info_attribute (tdesc, "vendor_id");
       const std::string target_id
 	= tdesc_find_device_info_attribute (tdesc, "target_id");
 
-      devices_to_print[std::make_tuple (pci_slot, subdevice_id, vendor_id,
+      devices_to_print[std::make_tuple (pci_slot, subdev_id, vendor_id,
 					target_id)].push_back (inf);
     }
 
@@ -1175,14 +1174,10 @@ print_devices (ui_out *uiout)
 	/* gdbarch is the same for all inferiors.  */
 	const target_desc *tdesc = gdbarch_target_desc (inf[0]->gdbarch);
 
-	const std::string pci_slot
-	  = tdesc_find_device_info_attribute (tdesc, "pci_slot");
-	const std::string subdevice_id
-	  = tdesc_find_device_info_attribute (tdesc, "subdevice_id");
-	const std::string vendor_id
-	  = tdesc_find_device_info_attribute (tdesc, "vendor_id");
-	const std::string target_id
-	  = tdesc_find_device_info_attribute (tdesc, "target_id");
+	const std::string &pci_slot = std::get<0> (device_id_desc_pair.first);
+	const std::string &subdev_id = std::get<1> (device_id_desc_pair.first);
+	const std::string &vendor_id = std::get<2> (device_id_desc_pair.first);
+	const std::string &target_id = std::get<3> (device_id_desc_pair.first);
 	const std::string total_cores
 	  = tdesc_find_device_info_attribute (tdesc, "total_cores");
 	const std::string device_name
@@ -1208,10 +1203,10 @@ print_devices (ui_out *uiout)
 			      ? string_printf ("%s", pci_slot.c_str ())
 			      : string_printf ("[%s]", pci_slot.c_str ())));
 
-	if (subdevice_id.empty ())
+	if (subdev_id.empty ())
 	  uiout->field_string ("sub-device", "-");
 	else
-	  uiout->field_string ("sub-device", subdevice_id.c_str ());
+	  uiout->field_string ("sub-device", subdev_id.c_str ());
 
 	uiout->field_string ("vendor-id", vendor_id.c_str ());
 
