@@ -1,7 +1,6 @@
 /* Cache and manage the values of registers for GDB, the GNU debugger.
 
    Copyright (C) 1986-2022 Free Software Foundation, Inc.
-   Copyright (C) 2020-2022 Intel Corporation
 
    This file is part of GDB.
 
@@ -154,7 +153,14 @@ register_type (struct gdbarch *gdbarch, int regnum)
   struct regcache_descr *descr = regcache_descr (gdbarch);
 
   gdb_assert (regnum >= 0 && regnum < descr->nr_cooked_registers);
-  return descr->register_type[regnum];
+
+  /* Some architectures have variable length pseudo registers, whose type
+     needs to be re-evaluated at runtime.  */
+  type *t = descr->register_type[regnum];
+  if (gdbarch_num_regs (gdbarch) < regnum && t->is_dyn_register ())
+    t = gdbarch_register_type (gdbarch, regnum);
+
+  return t;
 }
 
 /* Utility functions returning useful register attributes stored in
